@@ -49,8 +49,11 @@ class WebsocketRunServer(WebsocketWSGIServer):
             ('Upgrade', 'websocket'),
             ('Connection', 'Upgrade'),
             ('Sec-WebSocket-Accept', sec_ws_accept),
-            ('Sec-WebSocket-Version', str(websocket_version)),
+            ('Sec-WebSocket-Version', str(websocket_version))
         ]
+        if environ.get('HTTP_SEC_WEBSOCKET_PROTOCOL') is not None:
+            headers.append(('Sec-WebSocket-Protocol', environ.get('HTTP_SEC_WEBSOCKET_PROTOCOL')))
+
         logger.debug('WebSocket request accepted, switching protocols')
         start_response(force_str('101 Switching Protocols'), headers)
         six.get_method_self(start_response).finish_content()
